==> AGXUnreal-1.17.0_UE-5.6_Linux.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Physics3D/Interactions/Flexibility/LinearElasticBallFlexibility.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Physics3D/Physics3DForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics3D/Interactions/Flexibility/DefaultBallFlexibility.h>
#include <openplx/Physics/Interactions/Flexibility/LinearElastic.h>
/* Generated code for model LinearElasticBallFlexibility */
namespace openplx::Physics3D::Interactions::Flexibility {
    /**
     *     Define a linear elastic flexibility model for each constrained degree of freedom for a Ball.
     *     */
    class LinearElasticBallFlexibility : public openplx::Physics3D::Interactions::Flexibility::DefaultBallFlexibility {
        protected:
            double m_default_stiffness;

        public:
            LinearElasticBallFlexibility();
            double default_stiffness() const;
            std::shared_ptr<openplx::Physics::Interactions::Flexibility::LinearElastic> along_main() const;
            std::shared_ptr<openplx::Physics::Interactions::Flexibility::LinearElastic> along_normal() const;
            std::shared_ptr<openplx::Physics::Interactions::Flexibility::LinearElastic> along_cross() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

==> AGXUnreal-2.1.1_UE-5.5_Linux.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Physics3D/Interactions/Flexibility/LinearElasticBallFlexibility.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Physics3D/Physics3DBundleExport.h>
#include <openplx/Physics3D/Physics3DForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics3D/Interactions/Flexibility/DefaultBallFlexibility.h>
#include <openplx/Physics/Interactions/Flexibility/LinearElastic.h>

#ifdef _MSC_VER
#  pragma warning(push)
#  pragma warning(disable: 4251)
#endif

/* Generated code for model LinearElasticBallFlexibility */
namespace openplx::Physics3D::Interactions::Flexibility {
    /**
     *     Define a linear elastic flexibility model for each constrained degree of freedom for a Ball.
     *     */
    class OPENPLX_Physics3D_BUNDLE_EXPORT LinearElasticBallFlexibility : public openplx::Physics3D::Interactions::Flexibility::DefaultBallFlexibility {
        protected:
            double m_default_stiffness;

        public:
            LinearElasticBallFlexibility();
            virtual ~LinearElasticBallFlexibility();
            double default_stiffness() const;
            std::shared_ptr<openplx::Physics::Interactions::Flexibility::LinearElastic> along_main() const;
            std::shared_ptr<openplx::Physics::Interactions::Flexibility::LinearElastic> along_normal() const;
            std::shared_ptr<openplx::Physics::Interactions::Flexibility::LinearElastic> along_cross() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

#ifdef _MSC_VER
#  pragma warning(pop)
#endif
